@@ -1,5 +1,6 @@
 package Terse::Plugin::DBI;
-our $VERSION = '0.02'; use 5.006; use strict; use warnings;
+use 5.006; use strict; use warnings;
+our $VERSION = '0.03'; 
 use base 'Terse::Plugin';
 
 use DBI;
@@ -31,7 +32,7 @@ Terse::Plugin::DBI - DBI in Terse
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
